@@ -1,9 +1,3 @@
-"""
-.. testsetup::
-
-    from compas.geometry import Vector
-
-"""
 from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
@@ -21,8 +15,6 @@ from compas.geometry import transform_vectors
 
 from compas.geometry.primitives import Primitive
 
-__all__ = ['Vector']
-
 
 class Vector(Primitive):
     """A vector is defined by XYZ components and a homogenisation factor.
@@ -77,17 +69,6 @@ class Vector(Primitive):
 
     """
 
-    __slots__ = ['_x', '_y', '_z']
-
-    def __init__(self, x, y, z=0):
-        super(Vector, self).__init__()
-        self._x = 0.0
-        self._y = 0.0
-        self._z = 0.0
-        self.x = x
-        self.y = y
-        self.z = z
-
     @property
     def DATASCHEMA(self):
         from schema import Schema
@@ -95,18 +76,19 @@ class Vector(Primitive):
         return Schema(is_float3)
 
     @property
-    def JSONSCHEMA(self):
-        from compas import versionstring
-        schema = {
-            "$schema": "http://json-schema.org/draft-07/schema#",
-            "$id": "https://github.com/compas-dev/compas/schemas/vector.json",
-            "$compas": versionstring,
-            "type": "array",
-            "minItems": 3,
-            "maxItems": 3,
-            "items": {"type": "number"}
-        }
-        return schema
+    def JSONSCHEMANAME(self):
+        return 'vector'
+
+    __slots__ = ['_x', '_y', '_z']
+
+    def __init__(self, x, y, z=0.0, **kwargs):
+        super(Vector, self).__init__(**kwargs)
+        self._x = 0.0
+        self._y = 0.0
+        self._z = 0.0
+        self.x = x
+        self.y = y
+        self.z = z
 
     @property
     def data(self):
